@@ -1,20 +1,8 @@
 /*
-   Copyright 2007 David Nolden <david.nolden.kdevelop@art-master.de>
-   Copyright 2008 Niko Sams <niko.sams@gmail.com>
+    SPDX-FileCopyrightText: 2007 David Nolden <david.nolden.kdevelop@art-master.de>
+    SPDX-FileCopyrightText: 2008 Niko Sams <niko.sams@gmail.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "declarationnavigationcontext.h"
@@ -55,8 +43,8 @@ NavigationContextPointer DeclarationNavigationContext::registerChild(Declaration
 
 void DeclarationNavigationContext::htmlClass()
 {
-    StructureType::Ptr klass = declaration()->abstractType().cast<StructureType>();
-    Q_ASSERT(klass);
+    Q_ASSERT(declaration()->abstractType());
+    auto klass = declaration()->abstractType().staticCast<StructureType>();
     ClassDeclaration* classDecl = dynamic_cast<ClassDeclaration*>(klass->declaration(topContext().data()));
     if (classDecl) {
         // write class modifier
@@ -162,7 +150,7 @@ void DeclarationNavigationContext::htmlFunction()
   Q_ASSERT(function);
 
   const ClassFunctionDeclaration* classFunDecl = dynamic_cast<const ClassFunctionDeclaration*>(declaration().data());
-  const FunctionType::Ptr type = declaration()->abstractType().cast<FunctionType>();
+  const auto type = declaration()->abstractType().dynamicCast<FunctionType>();
   if( !type ) {
     modifyHtml() += errorHighlight(QStringLiteral("Invalid type<br />"));
     return;
@@ -194,11 +182,15 @@ void DeclarationNavigationContext::htmlFunction()
         modifyHtml() += QStringLiteral(", ");
       first = false;
 
-      VariableDeclaration *argDec = dynamic_cast<VariableDeclaration*>(decls[currentArgNum]);
+      VariableDeclaration *argDec = nullptr;
+
+      if (!decls.isEmpty()) {
+        argDec = dynamic_cast<VariableDeclaration*>(decls[currentArgNum]);
+      }
 
       if (argDec && argDec->isVariadic()) {
         AbstractType::Ptr variadicType;
-        const auto a_type = argType.cast<KDevelop::ArrayType>();
+        const auto a_type = argType.dynamicCast<KDevelop::ArrayType>();
         if (a_type) {
             variadicType = a_type->elementType();
         } else {
