@@ -1,22 +1,8 @@
-/***************************************************************************
- *   This file is part of KDevelop PHP support                             *
- *   Copyright 2012 Miha Čančula <miha@noughmad.eu>                        *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU Library General Public License as       *
- *   published by the Free Software Foundation; either version 2 of the    *
- *   License, or (at your option) any later version.                       *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU Library General Public     *
- *   License along with this program; if not, write to the                 *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2012 Miha Čančula <miha@noughmad.eu>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "phpunitrunjob.h"
 #include "phpunittestsuite.h"
@@ -24,6 +10,7 @@
 #include "testproviderdebug.h"
 
 #include <QStandardPaths>
+#include <QRegExp>
 
 #include <util/processlinemaker.h>
 #include <util/executecompositejob.h>
@@ -199,3 +186,5 @@ void PhpUnitRunJob::rowsInserted(const QModelIndex &parent, int startRow, int en
         }
     }
 }
+
+#include "moc_phpunitrunjob.cpp"
